<%
/**
 * Copyright (c) 2000-2008 Liferay, Inc. All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
%>

<%@ include file="/json_init.jsp" %>

<%
if (!themeDisplay.isSignedIn()) {
	return;
}

String activeBrowserKey = ParamUtil.getString(request, "activeBrowserKey");
boolean activeBrowser = ParamUtil.getBoolean(request, "activeBrowser");

// Status

Status status = null;

try {
	status = StatusLocalServiceUtil.getUserStatus(themeDisplay.getUserId());
}
catch (NoSuchStatusException nsse) {
}

if (!activeBrowser && (status != null) && !status.getActiveBrowserKey().equals(activeBrowserKey)) {

	// JSON

	JSONObject jsonObj = JSONFactoryUtil.createJSONObject();

	jsonObj.put("activeBrowser", false);
%>

	<%= jsonObj %>

<%
	return;
}

// Buddies

long buddiesModifiedDate = System.currentTimeMillis() - Time.MINUTE;

List<Object[]> buddies = null;

if (_BUDDY_LIST_STRATEGY.equals("all")) {
	buddies = StatusLocalServiceUtil.getAllStatuses(buddiesModifiedDate, 0, SearchContainer.DEFAULT_DELTA);
}
else if (_BUDDY_LIST_STRATEGY.equals("friends")) {
	buddies = StatusLocalServiceUtil.getSocialStatuses(themeDisplay.getUserId(), SocialRelationConstants.TYPE_BI_FRIEND, buddiesModifiedDate, 0, SearchContainer.DEFAULT_DELTA);
}
else {
	buddies = new ArrayList<Object[]>();
}

JSONArray buddiesJSON = JSONFactoryUtil.createJSONArray();

for (Object[] buddy : buddies) {
	long userId = (Long)buddy[0];
	String firstName = (String)buddy[1];
	String middleName = (String)buddy[2];
	String lastName = (String)buddy[3];
	long portraitId = (Long)buddy[4];

	String fullName = ContactConstants.getFullName(firstName, middleName, lastName);

	if (userId == themeDisplay.getUserId()) {
		continue;
	}

	JSONObject curUserJSON = JSONFactoryUtil.createJSONObject();

	curUserJSON.put("userId", userId);
	curUserJSON.put("fullName", fullName);
	curUserJSON.put("portraitId", portraitId);

	buddiesJSON.put(curUserJSON);
}

// Entries

long entriesCreateDate = ParamUtil.getLong(request, "createDate");

if (entriesCreateDate == 0) {
	if (status != null) {
		entriesCreateDate = status.getModifiedDate();
	}
	else {
		entriesCreateDate = System.currentTimeMillis() - Time.MINUTE;
	}
}

List<Entry> entries = EntryLocalServiceUtil.getNewEntries(themeDisplay.getUserId(), entriesCreateDate, 0, SearchContainer.DEFAULT_DELTA);

Collections.reverse(entries);

JSONArray entriesJSON = JSONFactoryUtil.createJSONArray();

for (Entry entry : entries) {
	JSONObject entryJSON = JSONFactoryUtil.createJSONObject();

	entryJSON.put("createDate", entry.getCreateDate());
	entryJSON.put("fromUserId", entry.getFromUserId());

	if (entry.getFromUserId() != themeDisplay.getUserId()) {
		User fromUser = UserLocalServiceUtil.getUserById(entry.getFromUserId());

		entryJSON.put("fromFullName", fromUser.getFullName());
		entryJSON.put("fromPortraitId", fromUser.getPortraitId());
	}

	entryJSON.put("toUserId", entry.getToUserId());
	entryJSON.put("content", entry.getContent());

	entriesJSON.put(entryJSON);
}

// Status

StatusLocalServiceUtil.updateStatus(themeDisplay.getUserId(), activeBrowserKey);

// JSON

JSONObject jsonObj = JSONFactoryUtil.createJSONObject();

jsonObj.put("activeBrowser", true);
jsonObj.put("buddies", buddiesJSON);
jsonObj.put("entries", entriesJSON);
%>

<%= jsonObj %>

<%!
private static final String _BUDDY_LIST_STRATEGY = GetterUtil.getString(PortletProps.get("buddy.list.strategy"));
%>